Learn R Programming

scOntoMatch (version 0.1.1)

getOntologyId: Get a names list of ontology and id by name

Description

Get a names list of ontology and id by name

Usage

getOntologyId(ont, onto_name)

Value

a named list mapping ontology id and ontology name

Arguments

ont

ontology object

onto_name

character vector of ontology names

Examples

Run this code
if (FALSE) {
getOntologyId(onto_name = "epithelial cell of lung", ont = ont)
}

Run the code above in your browser using DataLab