Learn R Programming

scOntoMatch (version 0.1.1)

getOntologyName: Get a names list of ontology and id by id

Description

Get a names list of ontology and id by id

Usage

getOntologyName(ont, onto_id)

Value

a named list mapping ontology id and ontology name

Arguments

ont

ontology object

onto_id

character vector of ontology ids

Examples

Run this code
if (FALSE) {
getOntologyName(onto_id = "epithelial cell of lung", ont = ont)
}

Run the code above in your browser using DataLab