Learn R Programming

scOntoMatch (version 0.1.1)

getSeuratRds: read in seurat object .rds files as a named list of seurat object

Description

read in seurat object .rds files as a named list of seurat object

Usage

getSeuratRds(metadata, sep)

Value

a named list contains data name and the corresponding 'seurat' object

Arguments

metadata

a metadata file indicating name, path to 'seurat' rds file

sep

sep of the metadata file

Examples

Run this code
if (FALSE) {
getSeuratRds(metadata = 'metadata.tsv', sep = '\t')
}

Run the code above in your browser using DataLab