powered by
Get a names list of ontology and id by name
getOntologyId(ont, onto_name)
a named list mapping ontology id and ontology name
ontology object
character vector of ontology names
if (FALSE) { getOntologyId(onto_name = "epithelial cell of lung", ont = ont) }
Run the code above in your browser using DataLab