powered by
Get a names list of ontology and id by id
getOntologyName(ont, onto_id)
a named list mapping ontology id and ontology name
ontology object
character vector of ontology ids
if (FALSE) { getOntologyName(onto_id = "epithelial cell of lung", ont = ont) }
Run the code above in your browser using DataLab