powered by
read in seurat object .rds files as a named list of seurat object
getSeuratRds(metadata, sep)
a named list contains data name and the corresponding 'seurat' object
a metadata file indicating name, path to 'seurat' rds file
sep of the metadata file
if (FALSE) { getSeuratRds(metadata = 'metadata.tsv', sep = '\t') }
Run the code above in your browser using DataLab