ontoMinimal: get the minimal ontology tree of a dataset by reducing descendant terms to ancestor terms
return obj meta.data[["cell_ontology_base"]] storing the reduced ontology annotation
Description
get the minimal ontology tree of a dataset by reducing descendant terms to ancestor terms
return obj meta.data[["cell_ontology_base"]] storing the reduced ontology annotation
Usage
ontoMinimal(obj, ont, anno_col, onto_id_col)
Value
an seurat object with meta.data[["cell_ontology_base"]]
Arguments
obj
the seurat object
ont
ontologyIndex object
anno_col
the cell ontology text annotation column name
onto_id_col
if also have ontology id column for direct mapping